@@ -1,9 +1,9 @@
-var itemsToShow = new Array();	//list of indexes to all dives to view
+var itemsToShow = new Array();	//list of indices to all dives to view
 var items = new Array();
 var start;			//index of first element viewed in itemsToShow
 var sizeofpage;			//size of viewed page
 var numberofwords = 0;		//just for stats
-var olditemstoshow;		//to reference the indexes to all dives if changed
+var olditemstoshow;		//to reference the indices to all dives if changed
 //////////////////////////////////
 //				//
 //		View Model	//
@@ -40,8 +40,8 @@ function viewInPage()
 }
 
 /**
-*addHTML this Method puts the HTML of items of given indexes
-*@param {array} indexes array of indexes to put in HTML
+*addHTML this Method puts the HTML of items of given indices
+*@param {array} indices array of indices to put in HTML
 */
 function updateView(start, end)
 {
@@ -56,17 +56,17 @@ function updateView(start, end)
 }
 
 /**
-*addHTML this Method puts the HTML of items of given indexes
-*@param {array} indexes array of indexes to put in HTML
+*addHTML this Method puts the HTML of items of given indices
+*@param {array} indices array of indices to put in HTML
 */
-function addHTML(indexes)
+function addHTML(indices)
 {
 	var divelist = document.getElementById('diveslist');
 	divelist.innerHTML = "";
-	for (var i = 0; i < indexes.length; i++) {
-		divelist.innerHTML += '<ul id="' + indexes[i] + '" onclick="toggleExpansion(event, this)"></ul>';
-		expand(document.getElementById(indexes[i]));
-		itemsToShow[indexes[i]].expanded = true;
+	for (var i = 0; i < indices.length; i++) {
+		divelist.innerHTML += '<ul id="' + indices[i] + '" onclick="toggleExpansion(event, this)"></ul>';
+		expand(document.getElementById(indices[i]));
+		itemsToShow[indices[i]].expanded = true;
 	};
 }
 
@@ -174,7 +174,6 @@ function setNumberOfDives(e)
 {
 	var value = e.options[e.selectedIndex].value;
 	sizeofpage = parseInt(value, 10);
-	var end = start + sizeofpage - 1;
 	viewInPage();
 }
 
@@ -224,14 +223,13 @@ function getExpanded(dive)
 {
 	var res = '<table><tr><td class="words">' + translate.Date + ': </td><td>' + dive.date +
 		  '</td><td class="words">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;' + translate.Time + ': </td><td>' + dive.time +
-		  '</td><td class="words">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;' + translate.Location + ': </td><td>' + '<a onclick=\"Search_list_Modules(\'' + dive.location + '\', {location:true, divemaster:false, buddy:false, notes:false, tags:false,})\">' + dive.location + '</a>' + getDiveCoor(dive) +
-		  '</td></tr></table><table><tr><td class="words">' + translate.Rating + ':</td><td>' + putRating(dive.rating) +
-		  '</td><td class="words">&nbsp;&nbsp;&nbsp;' + translate.Visibility + ':</td><td>' + putRating(dive.visibility) +
+		  '</td><td class="words">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;' + translate.Location + ': </td><td>' + '<a onclick=\"Search_list_Modules(\'' + dive.location + '\', {location:true, diveguide:false, buddy:false, notes:false, tags:false,})\">' + dive.location + '</a>' + getDiveCoor(dive) +
 		  '</td></tr></table>' +
 		  '<table><tr><td class="words">' + translate.Air_Temp + ': </td><td>' + dive.temperature.air +
 		  '</td><td class="words">&nbsp;&nbsp;&nbsp;&nbsp;' + translate.Water_Temp + ': </td><td>' + dive.temperature.water +
+		  '</td><td class="words">&nbsp;&nbsp;&nbsp;&nbsp;' + translate.Rating + ':</td><td>' + putRating(dive.rating) +
 		  '</td></tr></table><table><tr><td class="words">' + translate.Max_Depth + ': </td><td>' + put_depth_unit(dive.maxdepth) + " " + depth_unit + '</td></tr><tr><td class="words">' + translate.Duration + ': </td><td>' + dive.dive_duration +
-		  '</td></tr><tr><td class="words">' + translate.DiveMaster + ': </td><td>' + dive.divemaster +
+		  '</td></tr><tr><td class="words">' + translate.DiveGuide + ': </td><td>' + dive.diveguide +
 		  '</td></tr><tr><td class="words"><p>' + translate.Buddy + ': </p></td><td>' + dive.buddy +
 		  '</td></tr><tr><td class="words">' + translate.Suit + ': </td><td>' + dive.suit +
 		  '</td></tr><tr><td class="words">' + translate.Tags + ': </td><td>' + putTags(dive.tags) +
@@ -246,7 +244,7 @@ function putTags(tags)
 {
 	var result = "";
 	for (var i in tags) {
-		result += '<a onclick=\"Search_list_Modules(\'' + tags[i] + '\', {location:false, divemaster:false, buddy:false, notes:false, tags:true,})\">' + tags[i] + '</a>';
+		result += '<a onclick=\"Search_list_Modules(\'' + tags[i] + '\', {location:false, diveguide:false, buddy:false, notes:false, tags:true,})\">' + tags[i] + '</a>';
 		if (i < tags.length - 1)
 			result += ', ';
 	}
@@ -259,8 +257,7 @@ function putTags(tags)
 */
 function putRating(rating)
 {
-	var result;
-	result = '<div>';
+	var result = '<div>';
 	for (var i = 0; i < rating; i++)
 		result += ' &#9733; ';
 	for (var i = rating; i < 5; i++)
@@ -559,7 +556,7 @@ function SearchModules(searchfor, searchOptions)
 	if (searchOptions === null) {
 		searchOptions = {};
 		searchOptions.location = searchingModules["location"].enabled;
-		searchOptions.divemaster = searchingModules["divemaster"].enabled;
+		searchOptions.diveguide = searchingModules["diveguide"].enabled;
 		searchOptions.buddy = searchingModules["buddy"].enabled;
 		searchOptions.notes = searchingModules["notes"].enabled;
 		searchOptions.tags = searchingModules["tags"].enabled;
@@ -571,8 +568,8 @@ function SearchModules(searchfor, searchOptions)
 		if (searchOptions.location === true)
 			keywordResult.Union(searchingModules["location"].search(keywords[i]));
 
-		if (searchOptions.divemaster === true)
-			keywordResult.Union(searchingModules["divemaster"].search(keywords[i]));
+		if (searchOptions.diveguide === true)
+			keywordResult.Union(searchingModules["diveguide"].search(keywords[i]));
 
 		if (searchOptions.buddy === true)
 			keywordResult.Union(searchingModules["buddy"].search(keywords[i]));
@@ -683,7 +680,6 @@ var statsShows;
 */
 function toggleStats()
 {
-	var stats_button = document.getElementById('stats_button');
 	if (statsShows) {
 		statsShows = false;
 		document.getElementById('diveListPanel').style.display = 'block';
@@ -704,8 +700,7 @@ function showStats()
 
 function getDiveStats()
 {
-	var res = "";
-	res += '<table><tr id="stats_header">';
+	var res = '<table><tr id="stats_header">';
 	res += '<td class="statscell">' + translate.Year + '</td><td class="statscell">#</td><td class="statscell">' + translate.Total_Time + '</td><td class="statscell">' + translate.Average_Time + '</td><td class="statscell">' + translate.Shortest_Time + '</td><td class="statscell">' + translate.Longest_Time + '</td><td class="statscell">' + translate.Average_Depth + '</td><td class="statscell">' + translate.Min_Depth + '</td><td class="statscell">' + translate.Max_Depth + '</td><td class="statscell">' + translate.Average_SAC + '</td><td class="statscell">' + translate.Min_SAC + '</td><td class="statscell">' + translate.Max_SAC + '</td><td class="statscell">' + translate.Average_Temp + '</td><td class="statscell">' + translate.Min_Temp + '</td><td class="statscell">' + translate.Max_Temp + '</td>';
 	res += '</tr>';
 	res += getStatsRows();
@@ -753,6 +748,7 @@ function toggleTrips()
 	var trip_button = document.getElementById('trip_button');
 	var controller = document.getElementById('controller');
 	var no_dives_selector = document.getElementById('no_dives_selector');
+	var dives_controller = document.getElementById('controller');
 	if (tripsShown) {
 		tripsShown = false;
 		trip_button.style.backgroundColor = BACKGROUND_COLOR;
@@ -859,8 +855,7 @@ function get_weights_HTML(dive)
 	if (!dive.Weights.length)
 		return "";
 
-	var result = "";
-	result += '<table><tr><td class="words">' + translate.Weight + '</td><td class="words">' + translate.Type + '</td></tr>';
+	var result = '<table><tr><td class="words">' + translate.Weight + '</td><td class="words">' + translate.Type + '</td></tr>';
 	for (var i in dive.Weights) {
 		result += get_weight_HTML(dive.Weights[i]);
 	}
@@ -904,8 +899,7 @@ function get_cylinders_HTML(dive)
 	if (!dive.Cylinders.length)
 		return "";
 
-	var result = "";
-	result += '<h2 class="det_hed">' + translate.Dive_equipment + '</h2><table><tr><td class="words">' + translate.Type + '</td><td class="words">' + translate.Size + '</td><td class="words">' + translate.Work_Pressure + '</td><td class="words">' + translate.Start_Pressure + '</td><td class="words">' + translate.End_Pressure + '</td><td class="words">'+translate.Gas+'</td></tr>';
+	var result = '<h2 class="det_hed">' + translate.Dive_equipment + '</h2><table><tr><td class="words">' + translate.Type + '</td><td class="words">' + translate.Size + '</td><td class="words">' + translate.Work_Pressure + '</td><td class="words">' + translate.Start_Pressure + '</td><td class="words">' + translate.End_Pressure + '</td><td class="words">'+translate.Gas+'</td></tr>';
 	for (var i in dive.Cylinders) {
 		result += get_cylinder_HTML(dive.Cylinders[i]);
 	}
@@ -941,8 +935,7 @@ function get_bookmarks_HTML(dive)
 {
 	if (!dive.events || dive.events <= 0)
 		return "";
-	var result = "";
-	result += '<h2 class="det_hed">' + translate.Events + '</h2><table><tr><td class="words">' + translate.Name + '</td><td class="words">' + translate.Time + '</td><td class="words">' + translate.Value + '</td></tr>';
+	var result = '<h2 class="det_hed">' + translate.Events + '</h2><table><tr><td class="words">' + translate.Name + '</td><td class="words">' + translate.Time + '</td><td class="words">' + translate.Value + '</td></tr>';
 	for (var i in dive.events) {
 		result += get_bookmark_HTML(dive.events[i]);
 	}
@@ -950,10 +943,11 @@ function get_bookmarks_HTML(dive)
 	return result;
 }
 
-function getDiveCoorString(coordinates){
-	res = "";
-	lat = coordinates.lat;
-	lon = coordinates.lon;
+function getDiveCoorString(coordinates)
+{
+	var res = "";
+	var lat = coordinates.lat;
+	var lon = coordinates.lon;
 	res += float_to_deg(lat) + ' , ' + float_to_deg(lon);
 	return res;
 }
@@ -970,21 +964,31 @@ function getDiveCoor(dive)
 */
 function get_dive_HTML(dive)
 {
-	var res = '<h2 class="det_hed">' + translate.Dive_information + '</h2><table><tr><td class="words">' + translate.Date + ': </td><td>' + dive.date +
+	var table1 = '<h2 class="det_hed">' + translate.Dive_information + '</h2><table><tr><td class="words">' + translate.Date + ': </td><td>' + dive.date +
 		  '</td><td class="words">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;' + translate.Time + ': </td><td>' + dive.time +
-		  '</td><td class="words">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;' + translate.Location + ': </td><td>' + '<a onclick=\"Search_list_Modules(\'' + dive.location + '\', {location:true, divemaster:false, buddy:false, notes:false, tags:false,})\">' + dive.location + '</a></td>' + getDiveCoor(dive) +
-		  '</tr></table><table><tr><td class="words">' + translate.Rating + ':</td><td>' + putRating(dive.rating) +
-		  '</td><td class="words">&nbsp;&nbsp;&nbsp;' + translate.Visibility + ':</td><td>' + putRating(dive.visibility) +
-		  '</td></tr></table>' +
-		  '<table><tr><td class="words">' + translate.Air_Temp + ': </td><td>' + dive.temperature.air +
+		  '</td><td class="words">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;' + translate.Location + ': </td><td>' + '<a onclick=\"Search_list_Modules(\'' + dive.location + '\', {location:true, diveguide:false, buddy:false, notes:false, tags:false,})\">' + dive.location + '</a></td>' + getDiveCoor(dive) +
+		  '</tr></table>';
+	var table2 = '<table><tr><td class="words">' + translate.Rating + ':</td><td>' + putRating(dive.rating) + '</td>';
+	if (dive.wavesize > 0)
+		 table2 += '<td class="words">&nbsp;&nbsp;&nbsp;' + translate.WaveSize + ':</td><td>' + putRating(dive.wavesize) + '</td>';
+	if (dive.visibility > 0)
+		 table2 += '</td><td class="words">&nbsp;&nbsp;&nbsp;' + translate.Visibility + ':</td><td>' + putRating(dive.visibility) + '</td>';
+	if (dive.current > 0)
+		 table2 += '<td class="words">&nbsp;&nbsp;&nbsp;' + translate.Current + ':</td><td>' + putRating(dive.current) + '</td>';
+	if (dive.surge > 0)
+		 table2 += '<td class="words">&nbsp;&nbsp;&nbsp;' + translate.Surge + ':</td><td>' + putRating(dive.surge) + '</td>';
+	if (dive.chill > 0)
+		 table2 += '<td class="words">&nbsp;&nbsp;&nbsp;' + translate.Chill + ':</td><td>' + putRating(dive.chill) + '</td>';
+	table2 += '</tr></table>';
+	var table3 = '<table><tr><td class="words">' + translate.Air_Temp + ': </td><td>' + dive.temperature.air +
 		  '</td><td class="words">&nbsp;&nbsp;&nbsp;&nbsp;' + translate.Water_Temp + ': </td><td>' + dive.temperature.water +
 		  '</td></tr></table><table><tr><td class="words">' + translate.Max_Depth + ': </td><td>' + put_depth_unit(dive.maxdepth) + " " + depth_unit + '</td></tr><tr><td class="words">' + translate.Duration + ': </td><td>' + dive.dive_duration +
-		  '</td></tr><tr><td class="words">' + translate.DiveMaster + ': </td><td>' + dive.divemaster +
+		  '</td></tr><tr><td class="words">' + translate.DiveGuide + ': </td><td>' + dive.diveguide +
 		  '</td></tr><tr><td class="words"><p>' + translate.Buddy + ': </p></td><td>' + dive.buddy +
 		  '</td></tr><tr><td class="words">' + translate.Suit + ': </td><td>' + dive.suit +
 		  '</td></tr><tr><td class="words">' + translate.Tags + ': </td><td>' + putTags(dive.tags) +
 		  '</td></tr></table>'+ put_divecomputer_details(dive.divecomputers) +'<div style="margin:10px;"><p class="words">' + translate.Notes + ': </p>' + dive.notes + '</div>';
-	return res;
+	return table1 + table2 + table3;
 };
 
 function put_divecomputer_details(dc)
@@ -992,8 +996,7 @@ function put_divecomputer_details(dc)
 	if (dc.length <= 0)
 		return;
 
-	var res = '';
-	res += '<p style="margin:10px;" class="words">Divecomputer:</p>';
+	var res = '<p style="margin:10px;" class="words">Divecomputer:</p>';
 	for (var i =0; i < dc.length; i++) {
 		res += '<table>';
 		res += '<tr><td>Model : </td><td>' + dc[i].model + '</td></tr>';
@@ -1043,7 +1046,7 @@ function remove_missing_photos()
 	var actually_removed = 0;
 
 	console.log(missing_ids.length);
-	for(i = 0; i < missing_ids.length; i++){
+	for(var i = 0; i < missing_ids.length; i++){
 		dive.photos.splice(missing_ids[i] - actually_removed, 1);
 		actually_removed++;
 	}
@@ -1187,7 +1190,7 @@ function int_to_time(n)
 
 function float_to_deg(flt){
 	var deg = 0 | flt;
-	flt = (flt < 0 ? flt =- flt : flt);
+	flt = (flt < 0 ? - flt : flt);
         var min = 0 | flt % 1 * 60;
         var sec = (0 | flt * 60 % 1 * 6000) / 100;
         return deg + "&deg; " + min + "' " + sec + "\"";
